FlutterNosPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • FlutterNosPlatform
Implementers

Constructors

FlutterNosPlatform()
Constructs a FlutterNosPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

init(Map<String, Object>? config) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
uploadImage(String bucketName, String objName, String uploadToken, String imagePath) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ FlutterNosPlatform
The default instance of FlutterNosPlatform to use.
getter/setter pair